@@ -5,6 +5,7 @@ import py
 import argparse
 import subprocess
 import devpi
+from base64 import b64encode
 from devpi_common.types import lazydecorator, cached_property
 from devpi_common.url import URL
 from devpi_common.proc import check_output
@@ -92,11 +93,14 @@ class Hub:
             data = json.dumps(kvdict) if kvdict is not None else None
             if auth is notset:
                 auth = self.current.get_auth()
+            set_devpi_auth_header(headers, auth)
+            basic_auth = self.current.get_basic_auth(url=url)
+            cert = self.current.get_client_cert(url=url)
             r = self.http.request(method, url, data=data, headers=headers,
-                                  auth=auth)
-        except self.http.ConnectionError:
+                                  auth=basic_auth, cert=cert)
+        except self.http.ConnectionError as e:
             self._last_http_status = -1
-            self.fatal("could not connect to %r" % (url,))
+            self.fatal("could not connect to %r:\n%s" % (url, e))
         self._last_http_status = r.status_code
 
         if r.url != url:
@@ -134,7 +138,7 @@ class Hub:
             info = "%s %s\n" % (r.request.method, r.url)
         else:
             info = ""
-        message = reply.json_get("message", "")
+        message = reply.json_get("message", getattr(r, 'text', ''))
         if message:
             message = ": " + message
         out("%s%s %s%s" %(info, r.status_code, r.reason, message))
@@ -198,6 +202,10 @@ class Hub:
         args = [str(x) for x in args]
         if cwd == None:
             cwd = self.cwd
+        cmd = py.path.local.sysfind(args[0])
+        if not cmd:
+            self.fatal("command not found: %s" % args[0])
+        args[0] = str(cmd)
         if report:
             self.report_popen(args, cwd)
         return check_output(args, cwd=str(cwd))
@@ -278,6 +286,10 @@ class Hub:
         if not self.quiet:
             self.line(*msg, bold=True)
 
+    def warn(self, *msg):
+        if not self.quiet:
+            self.line(*msg, yellow=True, bold=True)
+
     def out_json(self, data):
         self._tw.line(json.dumps(data, sort_keys=True, indent=4))
 
@@ -317,6 +329,12 @@ class HTTPReply(object):
         return self._json[name]
 
 
+def set_devpi_auth_header(headers, auth):
+    if auth:
+        auth = "%s:%s" % auth
+        auth = b64encode(auth.encode("ascii")).decode("ascii")
+        headers["X-Devpi-Auth"] = auth
+
 class MyArgumentParser(argparse.ArgumentParser):
     class ArgumentError(Exception):
         """ and error from the argparse subsystem. """
@@ -450,6 +468,10 @@ def use(parser):
         help="show all available indexes at the remote server")
     parser.add_argument("--delete", action="store_true",
         help="delete current association with server")
+    parser.add_argument("--client-cert", action="store", default=None,
+        metavar="pem_file",
+        help="use the given .pem file as the SSL client certificate to "
+             "authenticate to the server (EXPERIMENTAL)")
     parser.add_argument("url", nargs="?",
         help="set current API endpoints to the ones obtained from the "
              "given url.  If already connected to a server, you can "
@@ -468,6 +490,19 @@ def getjson(parser):
         help="path to a resource to show information on. "
              "examples: '/', '/user', '/user/index'.")
 
+@subcommand("devpi.getjson:main_patchjson")
+def patchjson(parser):
+    """ send a PATCH request with the specified json content to
+    the specified path.
+
+    A low-level command to patch json requests at remote resources.
+    """
+    parser.add_argument("path", action="store",
+        help="path to a resource to patch information on. ")
+    parser.add_argument("jsonfile", action="store",
+        help="file to read json content from")
+
+
 @subcommand("devpi.list_remove:main_list", "list")
 def list_(parser):
     """ list project versions and files for the current index.
@@ -706,7 +741,7 @@ def install(parser):
     )
 
 def verify_reply_version(hub, reply):
-    acceptable_api_version = ("1",)
+    acceptable_api_version = ("2",)
     version = reply.headers.get("X-DEVPI-API-VERSION", None)
     if version is None:
         if not hasattr(hub, "_WARNAPI_DELIVERED"):
