@@ -3,7 +3,7 @@ import py
 from devpi import log
 from devpi_common.metadata import Version, BasenameMeta, get_pyversion_filetype
 from devpi_common.archive import zip_dir
-from .main import HTTPReply
+from .main import HTTPReply, set_devpi_auth_header
 
 def main(hub, args):
     # for now we use distutils/setup.py for register/upload commands.
@@ -102,22 +102,26 @@ class Uploader:
             pypi_action = "submit"
         dic[":action"] = pypi_action
         dic["protocol_version"] = "1",
+        headers = {}
         auth = hub.current.get_auth()
         if not auth:
             hub.fatal("need to be authenticated (use 'devpi login')")
+        set_devpi_auth_header(headers, auth)
         if path:
             files = {"content": (path.basename, path.open("rb"))}
         else:
             files = None
         if path:
-            msg = "%s of %s to %s" %(action, path.basename, hub.current.index)
+            msg = "%s of %s to %s" %(action, path.basename, hub.current.pypisubmit)
         else:
             msg = "%s %s-%s to %s" %(action, meta["name"], meta["version"],
-                                     hub.current.index)
+                                     hub.current.pypisubmit)
         if self.args.dryrun:
             hub.line("skipped: %s" % msg)
         else:
-            r = hub.http.post(hub.current.index, dic, files=files, auth=auth)
+            r = hub.http.post(hub.current.pypisubmit, dic, files=files,
+                              headers=headers, auth=hub.current.get_basic_auth(),
+                              cert=hub.current.get_client_cert())
             r = HTTPReply(r)
             if r.status_code == 200:
                 hub.info(msg)
