@@ -3,6 +3,15 @@ import pytest
 from devpi.list_remove import *
 from devpi import list_remove
 
+
+def linkver(index, basename, d=None, rel="releasefile"):
+    if d is None:
+        d = {}
+    links = d.setdefault("+links", [])
+    href = href="/{index}/+f/{basename}".format(index=index, basename=basename)
+    links.append(dict(href=href, rel=rel))
+    return d
+
 @pytest.mark.parametrize(["input", "output"], [
     (["pkg1", "pkg2"], ["*pkg1*", "*pkg2*"]),
 ])
@@ -12,15 +21,15 @@ def test_out_index(loghub, input, output):
     matcher.fnmatch_lines(output)
 
 @pytest.mark.parametrize(["input", "output"], [
-    ({"1.0": {"+files": {"p1-1.0.tar.gz": "root/dev/pkg/1.0/p1-1.0.tar.gz"},},
-      "1.1": {"+files": {"p1-1.1.tar.gz": "root/dev/pkg/1.1/p1-1.1.tar.gz"},},
-     }, ["*p1-1.1.tar.gz*", "*p1-1.0.tar.gz*", ]),
-    ({"1.0": {"+files": {"p1-1.0.tar.gz": "root/dev/pkg/1.0/p1-1.0.tar.gz"},
-              "+shadowing": [{"+files":
-                    {"p1-1.0.tar.gz": "root/prod/pkg/1.0/p1-1.0.tar.gz"}}]}},
-    ["*dev*p1-1.0.tar.gz*", "*prod*p1-1.0.tar.gz"]),
+    ({"1.0": linkver("root/dev", "p1-1.0.tar.gz"),
+      "1.1": linkver("root/dev", "p1-1.1.tar.gz")},
+     ["*p1-1.1.tar.gz*", "*p1-1.0.tar.gz*", ]),
+    #({"1.0": {"+links": dict(
+    #    rel="releasefile", href="root/dev/pkg/1.0/p1-1.0.tar.gz"),
+    #          "+shadowing": [{"+files":
+    #                {"p1-1.0.tar.gz": "root/prod/pkg/1.0/p1-1.0.tar.gz"}}]}},
+    #["*dev*p1-1.0.tar.gz*", "*prod*p1-1.0.tar.gz"]),
 ])
-
 def test_out_project(loghub, input, output, monkeypatch):
     loghub.current.reconfigure(dict(
                 simpleindex="/index",
@@ -29,13 +38,16 @@ def test_out_project(loghub, input, output, monkeypatch):
                 ))
     loghub.args.status = False
     loghub.args.all = True
-    monkeypatch.setattr(list_remove, "query_file_status", lambda *args: None)
-    out_project(loghub, input, parse_requirement("p1"))
+    monkeypatch.setattr(list_remove, "show_test_status", lambda *args: None)
+    class reply:
+        url = ""
+        result = input
+    out_project(loghub, reply, parse_requirement("p1"))
     matcher = loghub._getmatcher()
     matcher.fnmatch_lines(output)
 
     loghub.args.all = False
-    out_project(loghub, input, parse_requirement("p1"))
+    out_project(loghub, reply, parse_requirement("p1"))
     matcher = loghub._getmatcher()
     matcher.fnmatch_lines(output[0])
 
@@ -48,11 +60,8 @@ def test_confirm_delete(loghub, monkeypatch):
                 ))
     monkeypatch.setattr(loghub, "ask_confirm", lambda msg: True)
     class r:
-        result={"1.0": {
-                    "+files": {"x-1.0.tar.gz": "root/dev/files/x-1.0tar.gz"}},
-                "1.1": {
-                    "+files": {"x-1.1.tar.gz": "root/dev/files/x-1.1.tar.gz"}},
-        }
+        result={"1.0": linkver("root/dev", "x-1.0.tar.gz"),
+                "1.1": linkver("root/dev", "x-1.1.tar.gz")}
         type = "projectconfig"
     req = parse_requirement("x>=1.1")
     assert confirm_delete(loghub, r, req)
@@ -62,6 +71,7 @@ def test_confirm_delete(loghub, monkeypatch):
     """)
     assert "x-1.0" not in req
 
+
 def test_has_failing_commands():
     assert not has_failing_commands([dict(retcode="0"), dict(retcode="0")])
     assert has_failing_commands([dict(retcode="0"), dict(retcode="1")])
@@ -95,3 +105,5 @@ class TestList:
         devpi("remove", "-y", "hello==1.0", code=200)
         devpi("list", "hello")
         devpi("remove", "-y", "hello==1.1", code=200)
+        devpi("list")
+        devpi("list", "-v")
