@@ -28,12 +28,11 @@ class TestUnit:
                 pypisubmit="/post",
                 simpleindex="/index",
                 login="/login",
-                resultlog="/"))
+        ))
         assert current.simpleindex
         newcurrent = Current(path)
         assert newcurrent.pypisubmit == current.pypisubmit
         assert newcurrent.simpleindex == current.simpleindex
-        assert newcurrent.resultlog == current.resultlog
         assert newcurrent.venvdir == current.venvdir
         assert newcurrent.login == current.login
 
@@ -45,7 +44,7 @@ class TestUnit:
                 pypisubmit="/post",
                 simpleindex="/index",
                 login="/login",
-                resultlog="/"))
+        ))
         assert current.simpleindex
         current.reconfigure(dict(always_setcfg=True))
         newcurrent = Current(path)
@@ -127,6 +126,22 @@ class TestUnit:
         out, err = capfd.readouterr()
         assert "could not connect" in out
 
+    def test_use_with_basic_auth(self, cmd_devpi, mock_http_api):
+        mock_http_api.set(
+            "http://devpi/foo/bar/+api", 200, result=dict(
+                pypisubmit="/post",
+                simpleindex="/index/",
+                index="foo/bar",
+                bases="root/pypi",
+                login="/+login",
+                authstatus=["noauth", ""]))
+        # use with basic authentication
+        hub = cmd_devpi("use", "http://user:password@devpi/foo/bar")
+        assert hub.current.get_basic_auth() == ('user', 'password')
+        # now without basic authentication
+        hub = cmd_devpi("use", "http://devpi/foo/bar")
+        assert hub.current.get_basic_auth() is None
+
     def test_change_index(self, cmd_devpi, mock_http_api):
         mock_http_api.set("http://world.com/+api", 200,
                     result=dict(
@@ -153,7 +168,6 @@ class TestUnit:
                     result=dict(
                         pypisubmit="/post",
                         simpleindex="/index/",
-                        resultlog="/resultlog/",
                         index="root/some",
                         bases="root/dev",
                         login="/+login",
@@ -164,7 +178,6 @@ class TestUnit:
         newapi = hub.current
         assert newapi.pypisubmit == "http://world/post"
         assert newapi.simpleindex == "http://world/index/"
-        assert newapi.resultlog == "http://world/resultlog/"
         assert not newapi.venvdir
 
         # some url helpers
@@ -182,7 +195,6 @@ class TestUnit:
                     result=dict(
                         pypisubmit="",
                         simpleindex="",
-                        resultlog="/resultlog/",
                         index="",
                         bases="",
                         login="/+login",
@@ -226,7 +238,6 @@ class TestUnit:
                     result=dict(
                         pypisubmit="",
                         simpleindex="/simple",
-                        resultlog="/resultlog/",
                         index="/",
                         bases="",
                         login="/+login",
